@@ -24,7 +24,7 @@
 #include <QStandardItemModel>
 
 #include "ui_typepage.h"
-
+class QSortFilterProxyModel;
 class TypePage : public Page
 {
     Q_OBJECT
@@ -39,9 +39,11 @@ Q_SIGNALS:
 
 private:
     void selectionChanged();
+    void slotTextChanged(const QString &text);
 
     Ui::TypePage ui;
     QStandardItemModel *m_model = nullptr;
+    QSortFilterProxyModel *mProxy = nullptr;
 };
 
 #endif
